@@ -1,7 +1,7 @@
 import json
 import unittest
+from decimal import Decimal
 
-import dezimal
 import yaml
 
 from jinsi import *
@@ -13,7 +13,7 @@ class JinsiTestCase(unittest.TestCase):
     def check(self, expected, doc: str, dezimal_foo: bool = False, args: dict = None):
         rendered = render1s(doc, as_json=True, args=args)
         if dezimal_foo:
-            self.assertEqual(expected, json.loads(rendered, parse_int=dezimal.Dezimal, parse_float=dezimal.Dezimal))
+            self.assertEqual(expected, json.loads(rendered, parse_int=Decimal, parse_float=Decimal))
         else:
             self.assertEqual(expected, json.loads(rendered))
 
@@ -24,7 +24,7 @@ class JinsiTestCase(unittest.TestCase):
             self.assertEqual(expected, yaml.safe_load(rendered))
 
         if dezimal_foo:
-            loaded = load1s(doc, numtype=dezimal.Dezimal, args=args)
+            loaded = load1s(doc, numtype=Decimal, args=args)
         else:
             loaded = load1s(doc, args=args)
         self.assertEqual(expected, loaded)
